@@ -28,7 +28,7 @@
 #include <unistd.h>
 
 /* Forward declaration, this must be defined manually or using GCK_DEFINE_MODULE */
-static GckModule* gck_module_instantiate (CK_C_INITIALIZE_ARGS_PTR args);
+static GckModule* gck_module_instantiate (CK_C_INITIALIZE_ARGS_PTR args, GMutex *mutex);
 
 static GckModule *pkcs11_module = NULL;
 static pid_t pkcs11_module_pid = 0;
@@ -73,7 +73,7 @@ gck_C_Initialize (CK_VOID_PTR init_args)
 			else 
 				pkcs11_module_pid = pid;
 		} else {
-			pkcs11_module = gck_module_instantiate (args);
+			pkcs11_module = gck_module_instantiate (args, g_static_mutex_get_mutex (&pkcs11_module_mutex));
 			if (!pkcs11_module) {
 				g_warning ("module could not be instantiated");
 				rv = CKR_GENERAL_ERROR;
@@ -354,18 +354,11 @@ static CK_RV
 gck_C_InitPIN (CK_SESSION_HANDLE handle, CK_UTF8CHAR_PTR pin, CK_ULONG pin_len)
 {
 	CK_RV rv = CKR_CRYPTOKI_NOT_INITIALIZED;
-	GckSession *session;
 	
 	g_static_mutex_lock (&pkcs11_module_mutex);
 	
-		if (pkcs11_module != NULL) {
-			session = gck_module_lookup_session (pkcs11_module, handle);
-			if (session != NULL)
-				rv = gck_session_C_InitPIN (session,
-				                            pin, pin_len);
-			else
-				rv = CKR_SESSION_HANDLE_INVALID;
-		}
+		if (pkcs11_module != NULL)
+			rv = gck_module_C_InitPIN (pkcs11_module, handle, pin, pin_len);
 			
 	g_static_mutex_unlock (&pkcs11_module_mutex);
 
@@ -376,18 +369,11 @@ static CK_RV
 gck_C_SetPIN (CK_SESSION_HANDLE handle, CK_UTF8CHAR_PTR old_pin, CK_ULONG old_pin_len, CK_UTF8CHAR_PTR new_pin, CK_ULONG new_pin_len)
 {
 	CK_RV rv = CKR_CRYPTOKI_NOT_INITIALIZED;
-	GckSession *session;
 	
 	g_static_mutex_lock (&pkcs11_module_mutex);
 	
-		if (pkcs11_module != NULL) {
-			session = gck_module_lookup_session (pkcs11_module, handle);
-			if (session != NULL)
-				rv = gck_session_C_SetPIN (session,
-				                           old_pin, old_pin_len, new_pin, new_pin_len);
-			else
-				rv = CKR_SESSION_HANDLE_INVALID;
-		}
+		if (pkcs11_module != NULL)
+			rv = gck_module_C_SetPIN (pkcs11_module, handle, old_pin, old_pin_len, new_pin, new_pin_len);
 			
 	g_static_mutex_unlock (&pkcs11_module_mutex);
 
